@@ -24,6 +24,6 @@ class EmailConfigurationAdmin(admin.ModelAdmin):
                     'Email_Us',
                     'FAQ_URL',
                     'Unsubscribe_Email_ID',
-                    'Log_path',
+                    'Logs_Type',
                     'HTML_File',
-                    )
\ No newline at end of file
+                    )
