@@ -24,7 +24,11 @@ def send_log_email():
     sender = sender_email_configuration.sender_email_address
 
     email_configuration = EmailConfiguration.objects.filter(
-        Logs_Type='Attachment').all()
+        Logs_Type='Attachment').values('Subject', 'Logo', 'Banner',
+                                       'Email_Content', 'Signature',
+                                       'Email_Us', 'FAQ_URL',
+                                       'Unsubscribe_Email_ID', 'Logs_Type',
+                                       'HTML_File')
 
     send_notifications(email, sender, email_configuration)
 
@@ -33,7 +37,11 @@ def send_log_email_with_msg(email, sender, msg):
     """ function to send emails of log file to personas"""
 
     email_configuration = EmailConfiguration.objects.filter(
-        Logs_Type='Message').all()
+        Logs_Type='Message').values('Subject', 'Logo', 'Banner',
+                                    'Email_Content', 'Signature',
+                                    'Email_Us', 'FAQ_URL',
+                                    'Unsubscribe_Email_ID', 'Logs_Type',
+                                    'HTML_File')
 
     # Getting sender email id
     send_notifications_with_msg(email, sender, msg, email_configuration)
