@@ -45,6 +45,11 @@ class SenderEmailConfiguration(TimeStampedModel):
 class EmailConfiguration(TimeStampedModel):
     """Model for Email Configuration """
 
+    LOG_TYPE_CHOICES = (
+        ('attachment', 'ATTACHMENT'),
+        ('msg', 'MESSAGE'),
+    )
+
     Subject = models.CharField(max_length=200, null=True)
 
     Logo = models.ImageField(upload_to='logo_pic', default='logo.jpg',
@@ -62,11 +67,10 @@ class EmailConfiguration(TimeStampedModel):
 
     FAQ_URL = models.CharField(max_length=200, null=True)
 
-    Unsubscribe_Email_ID = models.EmailField(
-        max_length=254,
-        help_text='Enter email address')
-    Log_path = models.CharField(max_length=200, null=True)
-
+    Unsubscribe_Email_ID = models.EmailField(max_length=254,
+                                             help_text='Enter email address')
+    Logs_Type = models.CharField(max_length=200, choices=LOG_TYPE_CHOICES,
+                                 null=True)
     HTML_File = models.FileField(upload_to='HTML_files',
                                  help_text='Upload the html file')
 
